@@ -46,7 +46,7 @@ class IMobilethemeTwoSettings(form.Schema):
     
     #form.widget(scrape_url_pair=DataGridFieldFactory)
     scrape_url_pair = schema.List(
-        title = "Url Pair Fields",
+        title = _(u"scrape_url_pair", default=u"URL selector pairs"),
         value_type=DictRow(schema=IUrlPair),
     )
                   
